IIRC, it's a hack because neither x nor y is usually -32000, so those are flag 
values instead of fixed actual values. You have enough physical screens laid 
out in a line it's possible (16 1080p + a 1280 wide one), but still unlikely on 
one system given it would take multiple video cards to drive that many. The 
desktop as a decorated window hides the resize frame and title bar by 
positioning outside the effective area of a multiple screen layout and using a 
width and height that just encompasses the layout in Display Properties as the 
client area dimensions, with (0,0) of the viewports being one of the corners of 
the primary screen's client area. This forces at least one position coordinate 
to be negative by at least the width of the resize frame. I forget whether this 
is documented in the DDK or SDK,  sorry, and which edition.
------ Original message------From: James TaborDate: Sat, Feb 13, 2016 12:03 
AMTo: ReactOS Development List;Cc: Subject:[ros-dev] [ros-diffs] [hbelusca] 
70713: [WIN32SS] - Fix orthograph - Mention in the code that some stuff are 
hacks & need to be fixed. - Add parentheses around bit checks.
Hello,

Why is this a hack?

Thanks,
James


Modified: trunk/reactos/win32ss/user/ntuser/winpos.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/win32ss/user/ntuser/winpos.c?rev=70713&r1=70712&r2=70713&view=diff
==============================================================================
--- trunk/reactos/win32ss/user/ntuser/winpos.c  [iso-8859-1] (original)
+++ trunk/reactos/win32ss/user/ntuser/winpos.c  [iso-8859-1] Fri Feb 12
16:40:36 2016
@@ -724,8 +724,8 @@
    pwndParent = Window->spwndParent;
    if (pwndParent == UserGetDesktopWindow())
    {
-      ERR("Parent is Desktop, Min off screen!\n");
-      /* ReactOS doesn't support iconic minimize to desktop */
+      ERR("FIXME: Parent is Desktop, Min off screen!\n");
+      /* FIXME: ReactOS doesn't support iconic minimize to desktop */
       Pos->x = Pos->y = -32000;
       Window->InternalPos.flags |= WPF_MININIT;
       Window->InternalPos.IconPos.x = Pos->x;
_______________________________________________
Ros-dev mailing list
Ros-dev@reactos.org
http://www.reactos.org/mailman/listinfo/ros-dev
_______________________________________________
Ros-dev mailing list
Ros-dev@reactos.org
http://www.reactos.org/mailman/listinfo/ros-dev

Reply via email to